#!/usr/bin/perl -I/usr/sausalito/perl
#
# $Id: vz_vserver_backup_extend.pl, v 1.0.0.6 Thu 03 Jul 2008 05:25:00 AM CEST mstauber Exp $
# Copyright 2006-2008 Solarspeed Ltd. All rights reserved.
#
# This script is designed to tar up a local backup and to store it on another directory on
# the local filesystem. This can be a mounted network share for example (Samba or NFS).
#
# Please note: This is WAY less performant or practical than using RSYNC, but some may need it.

#
## Script enabler:
#

# Set this to "1" to enable this script:
$enabled = "0";

#
### Set this accordingly to your environment:
#

# Local source from which we fetch the data:
$localsource = "/vz/backup";

# Local target to which we copy the data:
$localtarget = "/samba/backup";

# Split Archives into multiple parts? Default: 1
$split = "1";

# Archive size. Default: 1000m (1 Gig)
$split_size = "1000m";

#
### No configureable options below:
#

use CCE;
use POSIX qw(isalpha);
use Socket;
use Sys::Hostname;
use File::Spec;

my $cce = new CCE;
$cce->connectuds();

$oid = $cce->event_oid();
$obj = $cce->event_object();

$host = hostname();
$addr = inet_ntoa(scalar(gethostbyname($host)) || 'localhost');
$now = localtime time;

# Remove stale lockfiles if it is older than 120 minutes:
if (-f "/tmp/vz_vserver_backup_extend.lock") {
        system("find /tmp/vz_vserver_backup_extend.lock -type f -cmin +120 -print | xargs rm >/dev/null 2>&1");
}

# Only run this script if it's been set to enabled:
if ($enabled != "1") {
        exit 0;
}

# Create lockfile:
system("/bin/touch /tmp/vz_vserver_backup_extend.lock");

# Print header:
print STDERR "=================================================================\n";
print STDERR "Running local storage agent to copy $localsource \n";
print STDERR "over to $localtarget\n";
print STDERR "=================================================================\n\n";

# Pack up the config file directories from $localsource into a tarball and
# store them in $localtarget:

print STDERR "Backing up config files ...\n\n";
system("/bin/rm -f $localtarget/config.tar.gz");
system("/bin/tar czf $localtarget/config.tar.gz /vz/backup/aconf /vz/backup/conf /vz/backup/uconf");
print STDERR "=================================================================\n\n";

# Dive into $localsource/vps/ and create tarballs for each VPS found in there.
# Store these in $localtarget/vps/

# Create $localtarget/vps if it doesn't exist:
if ( ! -d "$localtarget/vps" ) {
        system("/bin/mkdir $localtarget/vps");
}

# Get list of VPS's and sort them:
opendir(DIR,"$localsource/vps");
while($dirs = readdir(DIR)) {
        if (($dirs != "..") || ($dirs != ".")) {
                push (@vps, $dirs);
        }
}
closedir(DIR);
@vps_sorted = sort{$a<=>$b}(@vps);
print STDERR "Backing up VPS directories ...\n\n";
foreach $entry (@vps_sorted) {
        print STDERR "=================================================================\n\n";
	
	if ($split == "0") {
	        print STDERR "Storing backup of VPS $entry at $localtarget/vps/$entry.tar.gz \n";
        	system("/bin/rm -f $localtarget/vps/$entry.*");
        	system("/bin/tar czf $localtarget/vps/$entry.tar.gz /vz/backup/vps/$entry > /dev/null");
        	print STDERR "\n";
	}
	else {
	        print STDERR "Storing backup of VPS $entry at $localtarget/vps/$entry.tar.gz.* \n";
        	system("/bin/rm -f $localtarget/vps/$entry.*");
		system("/bin/tar czp /vz/backup/vps/$entry | /usr/bin/split -d -b $split_size - $localtarget/vps/$entry.tar.gz.");
        	print STDERR "\n";
	}
}

# Remove lockfile:
system("/bin/rm -f /tmp/vz_vserver_backup_extend.lock");

exit 0;

